datastructuretools.TreeNode
===========================

.. abjad-lineage:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode

.. autoclass:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.depth
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.graph_order
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.parent
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.root
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.name
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.__ge__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.__getstate__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.__gt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.__le__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.__lt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.__repr__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode.__setstate__
   :noindex:
